@@ -1,5 +1,5 @@
 # Copyright 2018 www.privaz.io Valletech AB
-# Copyright 2002-2021, OpenNebula Project, OpenNebula Systems
+# Copyright 2002-2023, OpenNebula Project, OpenNebula Systems
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ from lxml.etree import tostring
 from collections import OrderedDict
 from aenum import IntEnum
 
+TEMPLATE_ALWAYS_LIST_ELEM = ['SNAPSHOT']
 
 def cast2one(param):
 
@@ -86,6 +87,16 @@ def none2emptystr(d):
             d[k] = ""
 
 
+def fix_dict(d, tag):
+    if tag == 'TEMPLATE' and hasattr(d['TEMPLATE'], '__iter__'):
+        tmpl = d['TEMPLATE']
+
+        # wrap single entry as a list
+        for elem in TEMPLATE_ALWAYS_LIST_ELEM:
+            if elem in tmpl and type(tmpl[elem]) != list:
+                tmpl[elem] = [ tmpl[elem] ]
+
+
 def child2dict(element):
     '''
     Creates a dictionary from the documentTree obtained from a binding Element.
@@ -96,6 +107,9 @@ def child2dict(element):
     xml = tostring(element)
     ret = xmltodict.parse(xml, strip_whitespace=False)
 
+    # process dict, do ad-hoc fixes
+    fix_dict(ret, element.tag)
+
     # get the tag name and remove the ns attribute if present
     if "}" in element.tag:
         tagName = element.tag.split('}')[1]
@@ -110,6 +124,9 @@ def child2dict(element):
     # Replace 'None' values returned by xmltodict by ""
     none2emptystr(ret)
 
+    if not isinstance(ret[tagName], OrderedDict) and isinstance(ret[tagName], dict):
+        ret[tagName] = OrderedDict(ret[tagName])
+
     # return the contents dictionary, but save a reference
     ret[tagName]._root = ret
     return ret[tagName]
@@ -137,6 +154,6 @@ class TemplatedType(object):
     '''
     Mixin class for Templated bindings
     '''
-    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
+    def _buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
         if not build_template_node(self, nodeName_, child_):
-            super(TemplatedType, self).buildChildren(child_,node,nodeName_,fromsubclass_,gds_collector_)
+            super(TemplatedType, self)._buildChildren(child_,node,nodeName_,fromsubclass_,gds_collector_)
